Class-based generic views for Pyramid
=====================================

This code is a port of `Django's class-based generic views`_. The code was forked from
Django at `ec08d62a20`_ (1.7b1).

.. image:: https://badge.fury.io/py/pyramid-views.png
    :target: https://badge.fury.io/py/pyramid-views

.. image:: https://pypip.in/d/pyramid-views/badge.png
    :target: https://pypi.python.org/pypi/pyramid-views

Installation
------------

Installation using pip::

    pip install pyramid-views

Usage
-----

*Docs coming soon*

Credits
-------

This code is based upon the work of the `Django project`_.

pyramid-views is packaged using seed_.

.. _seed: https://github.com/adamcharnock/seed/
.. _Django's class-based generic views: https://docs.djangoproject.com/en/dev/ref/class-based-views/
.. _Django project: https://www.djangoproject.com/
.. _ec08d62a20: https://github.com/django/django/tree/ec08d62a20f55cfdfb9fbd21d8bc5627c54337c7